@@ -44,6 +44,11 @@ class SDKStub(object):
                 request_serializer=browserstack__sdk_dot_sdk__pb2.AutomationFrameworkStopRequest.SerializeToString,
                 response_deserializer=browserstack__sdk_dot_sdk__pb2.AutomationFrameworkStopResponse.FromString,
                 )
+        self.TestOrchestration = channel.unary_unary(
+                '/browserstack.sdk.v1.SDK/TestOrchestration',
+                request_serializer=browserstack__sdk_dot_sdk__pb2.TestOrchestrationRequest.SerializeToString,
+                response_deserializer=browserstack__sdk_dot_sdk__pb2.TestOrchestrationResponse.FromString,
+                )
         self.FindNearestHub = channel.unary_unary(
                 '/browserstack.sdk.v1.SDK/FindNearestHub',
                 request_serializer=browserstack__sdk_dot_sdk__pb2.FindNearestHubRequest.SerializeToString,
@@ -74,6 +79,11 @@ class SDKStub(object):
                 request_serializer=browserstack__sdk_dot_sdk__pb2.ObservabilityConfigRequest.SerializeToString,
                 response_deserializer=browserstack__sdk_dot_sdk__pb2.ObservabilityConfigResponse.FromString,
                 )
+        self.AccessibilityResult = channel.unary_unary(
+                '/browserstack.sdk.v1.SDK/AccessibilityResult',
+                request_serializer=browserstack__sdk_dot_sdk__pb2.AccessibilityResultRequest.SerializeToString,
+                response_deserializer=browserstack__sdk_dot_sdk__pb2.AccessibilityResultResponse.FromString,
+                )
         self.TestFrameworkEvent = channel.unary_unary(
                 '/browserstack.sdk.v1.SDK/TestFrameworkEvent',
                 request_serializer=browserstack__sdk_dot_sdk__pb2.TestFrameworkEventRequest.SerializeToString,
@@ -137,6 +147,11 @@ class SDKServicer(object):
         context.set_code(grpc.StatusCode.UNIMPLEMENTED)
         context.set_details('Method not implemented!')
         raise NotImplementedError('Method not implemented!')
+    def TestOrchestration(self, request, context):
+        """Missing associated documentation comment in .proto file."""
+        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
+        context.set_details('Method not implemented!')
+        raise NotImplementedError('Method not implemented!')
     def FindNearestHub(self, request, context):
         """Missing associated documentation comment in .proto file."""
         context.set_code(grpc.StatusCode.UNIMPLEMENTED)
@@ -167,6 +182,11 @@ class SDKServicer(object):
         context.set_code(grpc.StatusCode.UNIMPLEMENTED)
         context.set_details('Method not implemented!')
         raise NotImplementedError('Method not implemented!')
+    def AccessibilityResult(self, request, context):
+        """Missing associated documentation comment in .proto file."""
+        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
+        context.set_details('Method not implemented!')
+        raise NotImplementedError('Method not implemented!')
     def TestFrameworkEvent(self, request, context):
         """Missing associated documentation comment in .proto file."""
         context.set_code(grpc.StatusCode.UNIMPLEMENTED)
@@ -229,6 +249,11 @@ def add_SDKServicer_to_server(servicer, server):
                     request_deserializer=browserstack__sdk_dot_sdk__pb2.AutomationFrameworkStopRequest.FromString,
                     response_serializer=browserstack__sdk_dot_sdk__pb2.AutomationFrameworkStopResponse.SerializeToString,
             ),
+            'TestOrchestration': grpc.unary_unary_rpc_method_handler(
+                    servicer.TestOrchestration,
+                    request_deserializer=browserstack__sdk_dot_sdk__pb2.TestOrchestrationRequest.FromString,
+                    response_serializer=browserstack__sdk_dot_sdk__pb2.TestOrchestrationResponse.SerializeToString,
+            ),
             'FindNearestHub': grpc.unary_unary_rpc_method_handler(
                     servicer.FindNearestHub,
                     request_deserializer=browserstack__sdk_dot_sdk__pb2.FindNearestHubRequest.FromString,
@@ -259,6 +284,11 @@ def add_SDKServicer_to_server(servicer, server):
                     request_deserializer=browserstack__sdk_dot_sdk__pb2.ObservabilityConfigRequest.FromString,
                     response_serializer=browserstack__sdk_dot_sdk__pb2.ObservabilityConfigResponse.SerializeToString,
             ),
+            'AccessibilityResult': grpc.unary_unary_rpc_method_handler(
+                    servicer.AccessibilityResult,
+                    request_deserializer=browserstack__sdk_dot_sdk__pb2.AccessibilityResultRequest.FromString,
+                    response_serializer=browserstack__sdk_dot_sdk__pb2.AccessibilityResultResponse.SerializeToString,
+            ),
             'TestFrameworkEvent': grpc.unary_unary_rpc_method_handler(
                     servicer.TestFrameworkEvent,
                     request_deserializer=browserstack__sdk_dot_sdk__pb2.TestFrameworkEventRequest.FromString,
@@ -404,6 +434,22 @@ class SDK(object):
             options, channel_credentials,
             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
     @staticmethod
+    def TestOrchestration(request,
+            target,
+            options=(),
+            channel_credentials=None,
+            call_credentials=None,
+            insecure=False,
+            compression=None,
+            wait_for_ready=None,
+            timeout=None,
+            metadata=None):
+        return grpc.experimental.unary_unary(request, target, '/browserstack.sdk.v1.SDK/TestOrchestration',
+            browserstack__sdk_dot_sdk__pb2.TestOrchestrationRequest.SerializeToString,
+            browserstack__sdk_dot_sdk__pb2.TestOrchestrationResponse.FromString,
+            options, channel_credentials,
+            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
+    @staticmethod
     def FindNearestHub(request,
             target,
             options=(),
@@ -500,6 +546,22 @@ class SDK(object):
             options, channel_credentials,
             insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
     @staticmethod
+    def AccessibilityResult(request,
+            target,
+            options=(),
+            channel_credentials=None,
+            call_credentials=None,
+            insecure=False,
+            compression=None,
+            wait_for_ready=None,
+            timeout=None,
+            metadata=None):
+        return grpc.experimental.unary_unary(request, target, '/browserstack.sdk.v1.SDK/AccessibilityResult',
+            browserstack__sdk_dot_sdk__pb2.AccessibilityResultRequest.SerializeToString,
+            browserstack__sdk_dot_sdk__pb2.AccessibilityResultResponse.FromString,
+            options, channel_credentials,
+            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
+    @staticmethod
     def TestFrameworkEvent(request,
             target,
             options=(),
